#!/usr/bin/perl

# csv2pcp.pl - converts CSV files to PCP file format.
# Version 1.0 (12/9/2005)
# Syntax:
#        csv2pcp.pl file.csv
#        csv2pcp.pl file.csv file.pcp
#        cat file.csv | csv2pcp > file.pcp
#
# Copyright  Robert A Bradley 9 September 2005.

sub stripquotes {
    my ($x)=@_;
    $x=~s/\n//g;# Strip newlines
    $x=~s/^\s*//;
    $x=~s/\s*$//;
    $x=~s/^\"(.*)\"$/$1/;
    $x =~ s/([^\\])\"/$1/g;
    $x=~s/\"\"/\\\"/g;
    $x=~s/\\\"//g;
    return $x;
}

if ($#ARGV>=0) {
    my $file=$ARGV[0];
    open(FILE, "< $file") || die "Can't open $file";
}
else {
    open(FILE,"< -");
}
$header=<FILE>;
$header =~ /^([^,]*),([^,]*)(?:,([^,]*))?/;
$xh=&stripquotes($1);
$yh=&stripquotes($2);
$sigh=&stripquotes($3);
#if ($sigpresent=!($sigh eq "")) {
#    print "$xh, $yh, $sigh\n";
#}
#else {
#    print "$xh, $yh\n";
#}
my @lines;
while (<FILE>) {
    if ($sigpresent) {
        if (/^\s*([^,]*),\s*([^,]*),\s*([^,]*)$/) {
            $_ =~ /^\s*([^,]*),\s*([^,]*),\s*([^,]*)$/;
            $x=$1;$y=$2;$sig=$3;
            push @lines,[$x,$y,$sig];
        }
    }
    else {
        if (/^\s*([^,]*),\s*(.*)/) {
            $_ =~ /^\s*([^,]*),\s*(.*)/;
            $x=$1;$y=$2;
            push @lines,[$x+0,$y+0];
        }
    }
}
close FILE;

#print "Printing file...\n";

# Now we have the whole thing in a Perl array of arrays.
# Eventually, we will start processing it properly and plot it...
# ... but for now, we will dump it in pcp format

my $l=$#lines+1;
if ($#ARGV<1) {
    if ($sigpresent) {
        print "$l 1 1\n";
    }
    else {
        print "$l 1 0\n";
    }
    for $i (@lines) {
        my @x=(@{$i});
        print("$x[0] $x[1]\n");
    }
}
else {
    my $outfile=$ARGV[1];
    open(FILE, "> $outfile") || die "Can't open $outfile for writing";
    print "Saving PCP file to $outfile ... ";
    if ($sigpresent) {
        print FILE "$l 1 1\n";
    }
    else {
        print FILE "$l 1 0\n";
    }
    for $i (@lines) {
        my @x=(@{$i});
        print FILE "$x[0] $x[1]\n";
    }
    close FILE;
    print "done.\n";
}
