/*
  Name: gnuplot_ext.h
  Copyright: Copyright  Robert A Bradley 11/9/2005
  Author: Robert A Bradley
  Date: 11/09/2005 13:10
  Description: custom-written gnuplot_i function for plotting an array of Point
               structs (faster than gnuplot_plot_obj_xy)
               Requires gnuplot_i.c, pointlib.h includes
*/

int gnuplot_plot_Point_xy(
    gnuplot_ctrl *handle,
    Point *obj,
    int n,
    char *title
)
{
    int     i ;
	int		tmpfd ;
    char    name[128] ;
    char    cmd[GP_CMD_SIZE] ;
    char    line[GP_CMD_SIZE] ;

	if (handle==NULL || obj==NULL || (n<1)) return 1;

    /* Open one more temporary file? */
    if (handle->ntmp == GP_MAX_TMP_FILES - 1) {
        fprintf(stderr,
                "maximum # of temporary files reached (%d): cannot open more",
                GP_MAX_TMP_FILES) ;
        return 1;
    }

    /* Open temporary file for output   */
	sprintf(name, GNUPLOT_TEMPFILE, P_tmpdir);
    if ((tmpfd=mkstemp(name))==-1) {
        fprintf(stderr,"cannot create temporary file: exiting plot") ;
        return 1;
    }
    /* Store file name in array for future deletion */
    strcpy(handle->to_delete[handle->ntmp], name) ;
    handle->ntmp ++ ;

    /* Write data to this file  */
    for (i=0 ; i<n; i++) {
        sprintf(line, "%g %g\n", obj[i].x, obj[i].y) ;
		write(tmpfd, line, strlen(line));
    }
    close(tmpfd) ;

    /* Command to be sent to gnuplot    */
    if (handle->nplots > 0) {
        strcpy(cmd, "replot") ;
    } else {
        strcpy(cmd, "plot") ;
    }
    
    if (title == NULL) {
        sprintf(line, "%s \"%s\" with %s", cmd, name, handle->pstyle) ;
    } else {
        sprintf(line, "%s \"%s\" title \"%s\" with %s", cmd, name,
                      title, handle->pstyle) ;
    }

    /* send command to gnuplot  */
    gnuplot_cmd(handle, line) ;
    handle->nplots++ ;
    return 0;
}
